import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import Grid from "@material-ui/core/esm/Grid";
import MUIButton from "@material-ui/core/esm/Button";
import Typography from "@material-ui/core/esm/Typography";
import { makeStyles } from '@material-ui/core/styles';
import FormTemplate from '@data-driven-forms/common/form-template';
var useStyles = makeStyles(function () {
  return {
    buttonGroup: {
      display: 'flex',
      justifyContent: 'flex-end',
      '&>button:not(last-child)': {
        marginLeft: 8
      }
    }
  };
});

var Form = function Form(_ref) {
  var children = _ref.children,
      GridContainerProps = _ref.GridContainerProps,
      GridProps = _ref.GridProps,
      props = _objectWithoutProperties(_ref, ["children", "GridContainerProps", "GridProps"]);

  return /*#__PURE__*/React.createElement(Grid, _extends({
    item: true,
    xs: 12
  }, GridProps), /*#__PURE__*/React.createElement("form", _extends({
    noValidate: true
  }, props), /*#__PURE__*/React.createElement(Grid, _extends({
    container: true,
    item: true,
    spacing: 2,
    xs: 12
  }, GridContainerProps), children)));
};

Form.propTypes = {
  children: PropTypes.node,
  GridProps: PropTypes.object,
  GridContainerProps: PropTypes.object
};

var Description = function Description(_ref2) {
  var children = _ref2.children,
      GridProps = _ref2.GridProps,
      props = _objectWithoutProperties(_ref2, ["children", "GridProps"]);

  return /*#__PURE__*/React.createElement(Grid, _extends({
    item: true,
    xs: 12
  }, GridProps), /*#__PURE__*/React.createElement(Typography, _extends({
    variant: "body1",
    gutterBottom: true
  }, props), children));
};

Description.propTypes = {
  children: PropTypes.node,
  GridProps: PropTypes.object
};

var Title = function Title(_ref3) {
  var children = _ref3.children,
      GridProps = _ref3.GridProps,
      props = _objectWithoutProperties(_ref3, ["children", "GridProps"]);

  return /*#__PURE__*/React.createElement(Grid, _extends({
    item: true,
    xs: 12
  }, GridProps), /*#__PURE__*/React.createElement(Typography, _extends({
    variant: "h3",
    gutterBottom: true
  }, props), children));
};

Title.propTypes = {
  children: PropTypes.node,
  GridProps: PropTypes.object
};

var ButtonGroup = function ButtonGroup(_ref4) {
  var children = _ref4.children,
      GridProps = _ref4.GridProps,
      props = _objectWithoutProperties(_ref4, ["children", "GridProps"]);

  var classes = useStyles();
  return /*#__PURE__*/React.createElement(Grid, _extends({
    item: true,
    xs: 12
  }, GridProps), /*#__PURE__*/React.createElement("div", _extends({
    className: classes.buttonGroup
  }, props), children));
};

ButtonGroup.propTypes = {
  children: PropTypes.node,
  GridProps: PropTypes.object
};

var Button = function Button(_ref5) {
  var label = _ref5.label,
      variant = _ref5.variant,
      children = _ref5.children,
      buttonType = _ref5.buttonType,
      props = _objectWithoutProperties(_ref5, ["label", "variant", "children", "buttonType"]);

  return /*#__PURE__*/React.createElement(MUIButton, _extends({
    color: variant,
    variant: "contained"
  }, props), label || children);
};

Button.propTypes = {
  children: PropTypes.node,
  label: PropTypes.node,
  variant: PropTypes.string,
  buttonType: PropTypes.string
};

var MuiFormTemplate = function MuiFormTemplate(props) {
  return /*#__PURE__*/React.createElement(FormTemplate, _extends({
    FormWrapper: Form,
    Button: Button,
    ButtonGroup: ButtonGroup,
    Title: Title,
    Description: Description
  }, props));
};

export default MuiFormTemplate;